@@ -63,7 +63,8 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
     currency_digits = fields.Function(fields.Integer('Currency Digits'),
             'get_currency_digits')
     amount = fields.Numeric('Amount', digits=(16, Eval('currency_digits', 2)),
-            depends=['currency_digits'], help='Estimated revenue amount')
+        states=_STATES_STOP, depends=_DEPENDS_STOP + ['currency_digits'],
+        help='Estimated revenue amount')
     payment_term = fields.Many2One('account.invoice.payment_term',
         'Payment Term', states={
             'required': Eval('state') == 'converted',
@@ -277,18 +278,17 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
         Return sale for an opportunity
         '''
         Sale = Pool().get('sale.sale')
-        with Transaction().set_user(0, set_context=True):
-            return Sale(
-                description=self.description,
-                party=self.party,
-                payment_term=self.payment_term,
-                company=self.company,
-                invoice_address=self.address,
-                shipment_address=self.address,
-                currency=self.company.currency,
-                comment=self.comment,
-                sale_date=None,
-                )
+        return Sale(
+            description=self.description,
+            party=self.party,
+            payment_term=self.payment_term,
+            company=self.company,
+            invoice_address=self.address,
+            shipment_address=self.address,
+            currency=self.company.currency,
+            comment=self.comment,
+            sale_date=None,
+            )
 
     def create_sale(self):
         '''
@@ -432,15 +432,14 @@ class SaleOpportunityLine(ModelSQL, ModelView):
         Return sale line for opportunity line
         '''
         SaleLine = Pool().get('sale.line')
-        with Transaction().set_user(0, set_context=True):
-            sale_line = SaleLine(
-                type='line',
-                quantity=self.quantity,
-                unit=self.unit,
-                product=self.product,
-                sale=sale,
-                description=None,
-                )
+        sale_line = SaleLine(
+            type='line',
+            quantity=self.quantity,
+            unit=self.unit,
+            product=self.product,
+            sale=sale,
+            description=None,
+            )
         for k, v in sale_line.on_change_product().iteritems():
             setattr(sale_line, k, v)
         return sale_line
